CommittedVersion

Struct CommittedVersion 

pub struct CommittedVersion { /* private fields */ }
Committed version of the Transaction.

get_committed_version provides a value of this type. This value can be returned from run method closure. After the transaction successfully commits, you can use into method to get the committed version.